%define	with_bzip2		1
%define strip_binaries		1

# XXX legacy requires './' payload prefix to be omitted from rpm packages.
%define	_noPayloadPrefix	1

%define	__prefix	/usr
%{expand:%%define __share %(if [ -d %{__prefix}/share/man ]; then echo /share ; else echo %%{nil} ; fi)}

Summary:	The Red Hat package management system.
Name:		rpm
Version:	4.0.2
Release:	1.3.0
Group:		System Environment/Base
Source0:	ftp://ftp.rpm.org/pub/rpm/dist/rpm-4.0.x/rpm-%{version}.tar.gz
Source1:	engarde-gnupg-20011023.tar.gz
Patch0:		rpm-%{version}-engarde-gd-1.diff
Copyright:	GPL
Conflicts:	patch < 2.5
Prereq:		gawk fileutils textutils mktemp
Requires:	popt
BuildRequires:	db3-devel
BuildRequires:	bzip2 >= 0.9.0c-2
BuildRoot:	%{_tmppath}/%{name}-%{release}-root

%description
The RPM Package Manager (RPM) is a powerful command line driven
package management system capable of installing, uninstalling,
verifying, querying, and updating software packages.  Each software
package consists of an archive of files along with information about
the package like its version, a description, etc.

%package devel
Summary:	Development files for applications which will manipulate RPM packages.
Group:		Development/Libraries
Requires:	rpm = %{version}, popt

%description devel
This package contains the RPM C library and header files.  These
development files will simplify the process of writing programs which
manipulate RPM packages and databases. These files are intended to
simplify the process of creating graphical package managers or any
other tools that need an intimate knowledge of RPM packages in order
to function.

This package should be installed if you want to develop programs that
will manipulate RPM packages and databases.

%package build
Summary:	Scripts and executable programs used to build packages.
Group:		Development/Tools
Requires:	rpm = %{version}

%description build
This package contains scripts and executable programs that are used to
build packages using RPM.

%package -n popt
Summary:	A C library for parsing command line parameters.
Group:		Development/Libraries
Version:	1.6.2

%description -n popt
Popt is a C library for parsing command line parameters.  Popt was
heavily influenced by the getopt() and getopt_long() functions, but it
improves on them by allowing more powerful argument expansion.  Popt
can parse arbitrary argv[] style arrays and automatically set
variables based on command line arguments.  Popt allows command line
arguments to be aliased via configuration files and includes utility
functions for parsing arbitrary strings into argv[] arrays using
shell-like rules.

Install popt if you're a C programmer and you'd like to use its
capabilities.

%prep
%setup -q -b 0 -T 1
%patch0 -p1

%build
  CFLAGS="$RPM_OPT_FLAGS" \
  ./configure --prefix=%{__prefix} --sysconfdir=/etc --localstatedir=/var \
	--infodir='${prefix}%{__share}/info' --mandir='${prefix}%{__share}/man'
  make

%install
  [ "$RPM_BUILD_ROOT" != "/" ] && rm -rf $RPM_BUILD_ROOT

  make DESTDIR="$RPM_BUILD_ROOT" install

  mkdir -p $RPM_BUILD_ROOT/etc/rpm
  cat << E_O_F > $RPM_BUILD_ROOT/etc/rpm/macros.db1
%%_dbapi		1
E_O_F

%if %{strip_binaries}
{ cd $RPM_BUILD_ROOT
  strip ./bin/rpm
  strip .%{__prefix}/bin/rpm2cpio
}
%endif

  # Install our system-wide keyring.
  cd $RPM_BUILD_ROOT/usr/lib/rpm
  tar -zxf %{SOURCE1}
  mv engarde-gnupg gnupg


%pre
    if [ -f /var/lib/rpm/Packages -a -f /var/lib/rpm/packages.rpm ]; then
#    echo "
#You have both
#	/var/lib/rpm/packages.rpm	db1 format installed package headers
#	/var/lib/rpm/Packages		db3 format installed package headers
#Please remove (or at least rename) one of those files, and re-install.
#"
	exit 1
    fi
    exit 0

%post
    /sbin/ldconfig

    if [ -f /var/lib/rpm/packages.rpm ]; then
	: # do nothing
    elif [ -f /var/lib/rpm/Packages ]; then
	# undo db1 configuration
	rm -f /etc/rpm/macros.db1
    else
	# initialize db3 database
	rm -f /etc/rpm/macros.db1
	/bin/rpm --initdb
    fi

%postun -p /sbin/ldconfig

%post devel -p /sbin/ldconfig
%postun devel -p /sbin/ldconfig

%post -n popt -p /sbin/ldconfig
%postun -n popt -p /sbin/ldconfig

%files
  %defattr(-,root,root)
  %doc RPM-PGP-KEY RPM-GPG-KEY CHANGES GROUPS doc/manual/[a-z]*
  /bin/rpm
  %dir			/etc/rpm
  %config(missingok)	/etc/rpm/macros.db1
  %{__prefix}/bin/rpm2cpio
  %{__prefix}/bin/gendiff
  %{__prefix}/bin/rpmdb
  %{__prefix}/bin/rpm[eiukqv]
  %{__prefix}/bin/rpmsign
  %{__prefix}/bin/rpmquery
  %{__prefix}/bin/rpmverify
  %{__prefix}/lib/librpm.so.*
  %{__prefix}/lib/librpmio.so.*
  %{__prefix}/lib/librpmbuild.so.*

  %{__prefix}/lib/rpm/config.guess
  %{__prefix}/lib/rpm/config.sub
  %{__prefix}/lib/rpm/convertrpmrc.sh
  %{__prefix}/lib/rpm/macros
  %{__prefix}/lib/rpm/mkinstalldirs
  %{__prefix}/lib/rpm/rpmdb
  %{__prefix}/lib/rpm/rpm[eiukqv]
  %{__prefix}/lib/rpm/rpmpopt*
  %{__prefix}/lib/rpm/rpmrc

  %{__prefix}/lib/rpm/i[3456]86*

  %lang(cs)	%{__prefix}/*/locale/cs/LC_MESSAGES/rpm.mo
  %lang(da)	%{__prefix}/*/locale/da/LC_MESSAGES/rpm.mo
  %lang(de)	%{__prefix}/*/locale/de/LC_MESSAGES/rpm.mo
  %lang(fi)	%{__prefix}/*/locale/fi/LC_MESSAGES/rpm.mo
  %lang(fr)	%{__prefix}/*/locale/fr/LC_MESSAGES/rpm.mo
  %lang(is)	%{__prefix}/*/locale/is/LC_MESSAGES/rpm.mo
  %lang(ja)	%{__prefix}/*/locale/ja/LC_MESSAGES/rpm.mo
  %lang(no)	%{__prefix}/*/locale/no/LC_MESSAGES/rpm.mo
  %lang(pl)	%{__prefix}/*/locale/pl/LC_MESSAGES/rpm.mo
  %lang(pt)	%{__prefix}/*/locale/pt/LC_MESSAGES/rpm.mo
  %lang(pt_BR)	%{__prefix}/*/locale/pt_BR/LC_MESSAGES/rpm.mo
  %lang(ro)	%{__prefix}/*/locale/ro/LC_MESSAGES/rpm.mo
  %lang(ru)	%{__prefix}/*/locale/ru/LC_MESSAGES/rpm.mo
  %lang(sk)	%{__prefix}/*/locale/sk/LC_MESSAGES/rpm.mo
  %lang(sl)	%{__prefix}/*/locale/sl/LC_MESSAGES/rpm.mo
  %lang(sr)	%{__prefix}/*/locale/sr/LC_MESSAGES/rpm.mo
  %lang(sv)	%{__prefix}/*/locale/sv/LC_MESSAGES/rpm.mo
  %lang(tr)	%{__prefix}/*/locale/tr/LC_MESSAGES/rpm.mo

  %{__prefix}%{__share}/man/man[18]/*.[18]*
  %lang(pl)	%{__prefix}%{__share}/man/pl/man[18]/*.[18]*
  %lang(ru)	%{__prefix}%{__share}/man/ru/man[18]/*.[18]*
  %lang(sk)	%{__prefix}%{__share}/man/sk/man[18]/*.[18]*

  %dir %attr(755,root,admin)	/usr/lib/rpm/gnupg
  %attr(0444,root,root)		/usr/lib/rpm/gnupg/options
  %attr(0444,root,root)		/usr/lib/rpm/gnupg/pubring.gpg
  %attr(0400,root,root)		/usr/lib/rpm/gnupg/secring.gpg
  %attr(0644,root,root)		/usr/lib/rpm/gnupg/trustdb.gpg

%files build
  %defattr(-,root,root)
  %dir %{__prefix}/src/engarde
  %dir %{__prefix}/src/engarde/BUILD
  %dir %{__prefix}/src/engarde/SPECS
  %dir %{__prefix}/src/engarde/SOURCES
  %dir %{__prefix}/src/engarde/SRPMS
  %dir %{__prefix}/src/engarde/RPMS
  %{__prefix}/src/engarde/RPMS/*
  %{__prefix}/bin/rpmbuild
  %{__prefix}/lib/rpm/brp-*
  %{__prefix}/lib/rpm/check-prereqs
  %{__prefix}/lib/rpm/cpanflute
  %{__prefix}/lib/rpm/find-lang.sh
  %{__prefix}/lib/rpm/find-prov.pl
  %{__prefix}/lib/rpm/find-provides
  %{__prefix}/lib/rpm/find-provides.perl
  %{__prefix}/lib/rpm/find-req.pl
  %{__prefix}/lib/rpm/find-requires
  %{__prefix}/lib/rpm/find-requires.perl
  %{__prefix}/lib/rpm/get_magic.pl
  %{__prefix}/lib/rpm/getpo.sh
  %{__prefix}/lib/rpm/http.req
  %{__prefix}/lib/rpm/javadeps
  %{__prefix}/lib/rpm/magic.prov
  %{__prefix}/lib/rpm/magic.req
  %{__prefix}/lib/rpm/perl.prov
  %{__prefix}/lib/rpm/perl.req
  %{__prefix}/lib/rpm/rpm[bt]
  %{__prefix}/lib/rpm/rpmdiff
  %{__prefix}/lib/rpm/rpmdiff.cgi
  %{__prefix}/lib/rpm/u_pkg.sh
  %{__prefix}/lib/rpm/vpkg-provides.sh
  %{__prefix}/lib/rpm/vpkg-provides2.sh

%files devel
  %defattr(-,root,root)
  %{__prefix}/include/rpm
  %{__prefix}/lib/librpm.a
  %{__prefix}/lib/librpm.la
  %{__prefix}/lib/librpm.so
  %{__prefix}/lib/librpmio.a
  %{__prefix}/lib/librpmio.la
  %{__prefix}/lib/librpmio.so
  %{__prefix}/lib/librpmbuild.a
  %{__prefix}/lib/librpmbuild.la
  %{__prefix}/lib/librpmbuild.so

%files -n popt
  %defattr(-,root,root)
  %{__prefix}/lib/libpopt.so.*
  %{__prefix}%{__share}/man/man3/popt.3*
  %{__prefix}/lib/libpopt.a
  %{__prefix}/lib/libpopt.la
  %{__prefix}/lib/libpopt.so
  %{__prefix}/include/popt.h

  %lang(cs)	%{__prefix}/*/locale/cs/LC_MESSAGES/popt.mo
  %lang(da)	%{__prefix}/*/locale/da/LC_MESSAGES/popt.mo
  %lang(gl)	%{__prefix}/*/locale/gl/LC_MESSAGES/popt.mo
  %lang(hu)	%{__prefix}/*/locale/hu/LC_MESSAGES/popt.mo
  %lang(is)	%{__prefix}/*/locale/is/LC_MESSAGES/popt.mo
  %lang(no)	%{__prefix}/*/locale/no/LC_MESSAGES/popt.mo
  %lang(pt)	%{__prefix}/*/locale/pt/LC_MESSAGES/popt.mo
  %lang(ro)	%{__prefix}/*/locale/ro/LC_MESSAGES/popt.mo
  %lang(ru)	%{__prefix}/*/locale/ru/LC_MESSAGES/popt.mo
  %lang(sk)	%{__prefix}/*/locale/sk/LC_MESSAGES/popt.mo
  %lang(sl)	%{__prefix}/*/locale/sl/LC_MESSAGES/popt.mo
  %lang(sv)	%{__prefix}/*/locale/sv/LC_MESSAGES/popt.mo
  %lang(tr)	%{__prefix}/*/locale/tr/LC_MESSAGES/popt.mo
  %lang(uk)	%{__prefix}/*/locale/uk/LC_MESSAGES/popt.mo
  %lang(wa)	%{__prefix}/*/locale/wa/LC_MESSAGES/popt.mo
  %lang(zh_CN)	%{__prefix}/*/locale/zh_CN.GB2312/LC_MESSAGES/popt.mo

%clean
  [ "$RPM_BUILD_ROOT" != "/" ] && rm -rf $RPM_BUILD_ROOT

%changelog
* Thu Apr 10 2003 Ryan W. Maple <ryan@guardiandigital.com>
- Release 1.3.0
  - Initial build for EnGarde Secure Community 2 (Feint).

* Thu Feb 20 2003 Ryan W. Maple <ryan@guardiandigital.com>
- Version 4.0.2, Release 1.5.3
  - FOO
